BarcodeScannerController class

Constructors

BarcodeScannerController()

Properties

flashMode FlashMode
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

attachDetectBarcodeFromFile(Future<List<Barcode>> callback(File)) → void
Don't call it
attachPause(AsyncFunction callback) → void
Don't call it
attachResume(AsyncFunction callback) → void
Don't call it
attachSetFlashMode(Future<void> callback(FlashMode mode)) → void
Don't call it
detectBarcodeFromFile(File file) Future<List<Barcode>>
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() Future<void>
Pause camera and detector, It's auto call while barcode was detected
resume() Future<void>
Resume camera and detector
setFlashMode(FlashMode mode) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited