enableAutoZoom property
For auto zoom when barcode size is too small base on minBarcodeSizeThreshold for increase accuracy
Implementation
final bool enableAutoZoom;
For auto zoom when barcode size is too small base on minBarcodeSizeThreshold for increase accuracy
final bool enableAutoZoom;