ImageUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
buildAndroidInputImage(
CameraImage image, InputImageRotation rotation) → InputImage? -
buildIOSInputImage(
CameraImage image, InputImageRotation rotation) → InputImage? -
captureFrameAsPng(
{required CameraImage cameraImage, int rotation = 0, bool flipHorizontal = false}) → Future< Uint8List?> -
cropImage(
{required CameraImage cameraImage, required Rect cropRect, int rotation = 0, bool flipHorizontal = false}) → Future< Uint8List?>