BarcodeScannerView class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- BarcodeScannerView
Constructors
-
BarcodeScannerView({Key? key, required BarcodeScannerController controller, required dynamic onDetected(List<
Barcode> barcode), required dynamic onCompleted(), Size barcodeScanFrameSize = const Size(200, 200), BarcodeScannerAnimation animation = const BarcodeScannerAnimation(), double minBarcodeSizeThreshold = .01, bool enableAutoZoom = true, List<Widget> children = const [], Widget barcodeFrameViewBuilder(BuildContext context, Rect rect, Barcode? barcode)?, double barcodeFramePadding = 10.0, List<BarcodeFormat> formats = const [BarcodeFormat.all]}) -
const
Properties
- animation → BarcodeScannerAnimation
-
Animation config, enable by default if you don't want animation set enable : false
final
- barcodeFramePadding → double
-
final
- barcodeFrameViewBuilder → Widget Function(BuildContext context, Rect rect, Barcode? barcode)?
-
final
- barcodeScanFrameSize → Size
-
Scan area size for center barcode when scan multi barcode
final
-
children
→ List<
Widget> -
Custom overlay
final
- controller → BarcodeScannerController
-
final
- enableAutoZoom → bool
-
For auto zoom when barcode size is too small base on minBarcodeSizeThreshold
for increase accuracy
final
-
formats
→ List<
BarcodeFormat> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- minBarcodeSizeThreshold → double
-
Threshold for zoom barcode
final
- onCompleted → dynamic Function()
-
trigger when animation capture barcode complete
this callback not trigger if disable animation
final
-
onDetected
→ dynamic Function(List<
Barcode> barcode) -
trigger when barcode begin detected
Notic : Camera is pause by default while barcode begin detected
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< BarcodeScannerView> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited